Slave serial com

Dependencies:   mbed

Fork of Serial_Communication_Slave by Arthur Semjonov

Revision:
1:a1067f80d074
Parent:
0:3457fac208b7
Child:
2:b7eee254a06e
diff -r 3457fac208b7 -r a1067f80d074 TARDIS_ARCHIVE.h
--- a/TARDIS_ARCHIVE.h	Tue Feb 18 16:31:38 2014 +0000
+++ b/TARDIS_ARCHIVE.h	Tue Feb 18 16:38:12 2014 +0000
@@ -3,7 +3,7 @@
  * music.h
  *
  *  Created on: Feb "some day", 2014
- *     Authors: COSC 4290 Students of Dr Dennis Brylow. 
+ *     Authors: Arthur Semjonov && Jonathan Pucceti 
  */
 
 #ifndef TARDIS_H_
@@ -54,11 +54,11 @@
 
 /* _________________________________________
  * Parses the note recevied by the I2C slave.
  * Helper function of playTheCompanion. Which takes and integer value and references the frequency
  * related to that note. After frequency is found, function plays the note.
  * @param k, music note
  * _________________________________________ */
-void playTheCompanion(int k);
+void playTheNote(int k);
 
 /* _________________________________________________________________________
  * I2C data link (Master) which sends notes of the song to linked slave mbed
@@ -76,6 +76,6 @@
             1) Hold mid joystick to stop both master and slave
             2) When Master button is pressed (joyUp), it will stop playing slave song and 
 _________________________________________________________________________________________*/
-void playTheCompanion(void);
+void playTheNote(void);
 
 #endif /* TARDIS_H_ */
\ No newline at end of file
@@ -54,11 +54,11 @@
 /* _________________________________________
  * Parses the note recevied by the I2C slave.
- * Helper function of playTheCompanion. Which takes and integer value and references the frequency
+ * Helper function of playTheNote. Which takes and integer value and references the frequency
  * related to that note. After frequency is found, function plays the note.
  * @param k, music note